/*
 * Squawk messenger.
 * Copyright (C) 2019 Yury Gubich <blue@macaw.me>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "settingslist.h"

SettingsList::SettingsList(QWidget* parent):
    QListWidget(parent),
    lastWidth(0)
{

}

SettingsList::~SettingsList()
{
}

QStyleOptionViewItem SettingsList::viewOptions() const
{
    QStyleOptionViewItem option = QListWidget::viewOptions();
    if (!iconSize().isValid()) {
        option.decorationSize.setWidth(lastWidth);
    }
    option.rect.setWidth(lastWidth);
    return option;
}

void SettingsList::resizeEvent(QResizeEvent* event)
{
    lastWidth = event->size().width();
    QListWidget::resizeEvent(event);
}

QRect SettingsList::visualRect(const QModelIndex& index) const
{
    QRect res = QListWidget::visualRect(index);
    if (index.isValid()) {
        res.setWidth(lastWidth);
    }
    return res;
}

